==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebRowDataEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowDataEventArgsDetailDescriptionMetadata } from "./WebRowDataEventArgsDetailDescriptionMetadata";
import { WebRowDataEventArgsDescription } from "./WebRowDataEventArgsDescription";
/**
 * @hidden
 */
var WebRowDataEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebRowDataEventArgsDescriptionMetadata, _super);
    function WebRowDataEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRowDataEventArgsDescriptionMetadata.b = function (a) {
        if (WebRowDataEventArgsDescriptionMetadata.a == null) {
            WebRowDataEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRowDataEventArgsDescriptionMetadata.c(WebRowDataEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebRowDataEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebRowDataEventArgsDescriptionMetadata.a);
        WebRowDataEventArgsDetailDescriptionMetadata.d(a);
    };
    WebRowDataEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:RowDataEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebRowDataEventArgsDetail");
    };
    WebRowDataEventArgsDescriptionMetadata.d = function (a) {
        WebRowDataEventArgsDescriptionMetadata.b(a);
        a.ac("WebRowDataEventArgs", function () { return new WebRowDataEventArgsDescription(); });
        a.ab("WebRowDataEventArgs", WebRowDataEventArgsDescriptionMetadata.a);
    };
    WebRowDataEventArgsDescriptionMetadata.$t = markType(WebRowDataEventArgsDescriptionMetadata, 'WebRowDataEventArgsDescriptionMetadata');
    WebRowDataEventArgsDescriptionMetadata.a = null;
    return WebRowDataEventArgsDescriptionMetadata;
}(Base));
export { WebRowDataEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebRowDataEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowDataEventArgsDetailDescriptionMetadata } from "./WebRowDataEventArgsDetailDescriptionMetadata";
import { WebRowDataEventArgsDescription } from "./WebRowDataEventArgsDescription";
/**
 * @hidden
 */
var WebRowDataEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRowDataEventArgsDescriptionMetadata, _super);
    function WebRowDataEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRowDataEventArgsDescriptionMetadata.b = function (a) {
        if (WebRowDataEventArgsDescriptionMetadata.a == null) {
            WebRowDataEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRowDataEventArgsDescriptionMetadata.c(WebRowDataEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebRowDataEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebRowDataEventArgsDescriptionMetadata.a);
        WebRowDataEventArgsDetailDescriptionMetadata.d(a);
    };
    WebRowDataEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:RowDataEventArgs");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebRowDataEventArgsDetail");
    };
    WebRowDataEventArgsDescriptionMetadata.d = function (a) {
        WebRowDataEventArgsDescriptionMetadata.b(a);
        a.ae("WebRowDataEventArgs", function () { return new WebRowDataEventArgsDescription(); });
        a.ad("WebRowDataEventArgs", WebRowDataEventArgsDescriptionMetadata.a);
    };
    WebRowDataEventArgsDescriptionMetadata.$t = markType(WebRowDataEventArgsDescriptionMetadata, 'WebRowDataEventArgsDescriptionMetadata');
    WebRowDataEventArgsDescriptionMetadata.a = null;
    return WebRowDataEventArgsDescriptionMetadata;
}(Base));
export { WebRowDataEventArgsDescriptionMetadata };
